==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Input/vorbis/translations/vorbis_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis 插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="56"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis 文件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="132"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>关于 Ogg Vorbis 音频插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="133"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis 音频插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="134"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="135"/>
        <source>Source code based on mq3 project</source>
        <translation>源代码基于 mq3 项目</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>长度</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>声音通道</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/Input/vorbis/translations/vorbis_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="55"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis 插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="58"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis 文件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="137"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>关于 Ogg Vorbis 音频插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="138"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis 音频插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="139"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="140"/>
        <source>Source code based on mq3 project</source>
        <translation>源代码基于 mq3 项目</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>长度</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>赫兹</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>声音通道</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation>千比特每秒</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>千字节</translation>
    </message>
</context>
</TS>
